Crate optical_flow_lk

Crate optical_flow_lk 

High-performance computer vision algorithms for real-time applications

Provides implementations of:

  • Lucas-Kanade optical flow
  • Shi-Tomasi feature detection
  • Optimized image processing pipelines

Designed to be compatible with WebAssembly (Wasm).

Functions

build_pyramid
Builds a pyramid of images where each successive layer is half as large in width and height
calc_optical_flow
Compute optical flow using Lucas-Kanade method
good_features_to_track
Finds good features points using the Shi-Tomasi algorithm