High-performance computer vision algorithms for real-time applications
Provides implementations of:
- Lucas-Kanade optical flow
- Shi-Tomasi feature detection
- Optimized image processing pipelines
Designed to be compatible with WebAssembly (Wasm).
Functions
- build_
pyramid - Builds a pyramid of images where each successive layer is half as large in width and height
- calc_
optical_ flow - Compute optical flow using Lucas-Kanade method
- good_
features_ to_ track - Finds good features points using the Shi-Tomasi algorithm